@@ -3,15 +3,17 @@
     (part of web.py modules)
 """
 import unittest
-import sys, os
+import sys
 import web
 
 TestCase = unittest.TestCase
 TestSuite = unittest.TestSuite
 
+
 def load_modules(names):
     return [__import__(name, None, None, "x") for name in names]
 
+
 def module_suite(module, classnames=None):
     """Makes a suite from a module."""
     if classnames:
@@ -21,6 +23,7 @@ def module_suite(module, classnames=None):
     else:
         return unittest.TestLoader().loadTestsFromModule(module)
 
+
 def doctest_suite(module_names):
     """Makes a test suite from doctests."""
     import doctest
@@ -28,7 +31,8 @@ def doctest_suite(module_names):
     for mod in load_modules(module_names):
         suite.addTest(doctest.DocTestSuite(mod))
     return suite
-    
+
+
 def suite(module_names):
     """Creates a suite from multiple modules."""
     suite = TestSuite()
@@ -36,10 +40,12 @@ def suite(module_names):
         suite.addTest(module_suite(mod))
     return suite
 
+
 def runTests(suite):
     runner = unittest.TextTestRunner()
     return runner.run(suite)
 
+
 def main(suite=None):
     if not suite:
         main_module = __import__('__main__')
