@@ -5,14 +5,15 @@ General Utilities
 """
 
 __all__ = [
-  "Storage", "storage" 
+    "Storage", "storage"
 ]
 
+
 class Storage(dict):
     """
     A Storage object is like a dictionary except `obj.foo` can be used
     in addition to `obj['foo']`. (part of web.py)
-    
+
         >>> o = storage(a=1)
         >>> o.a
         1
@@ -26,24 +27,24 @@ class Storage(dict):
         Traceback (most recent call last):
             ...
         AttributeError: 'a'
-    
+
     """
-    def __getattr__(self, key): 
+    def __getattr__(self, key):
         try:
             return self[key]
-        except KeyError, k:
-            raise AttributeError, k
-    
-    def __setattr__(self, key, value): 
+        except KeyError, e:
+            raise AttributeError, e
+
+    def __setattr__(self, key, value):
         self[key] = value
-    
+
     def __delattr__(self, key):
         try:
             del self[key]
-        except KeyError, k:
-            raise AttributeError, k
-    
-    def __repr__(self):     
+        except KeyError, e:
+            raise AttributeError, e
+
+    def __repr__(self):
         return '<Storage ' + dict.__repr__(self) + '>'
 
 storage = Storage
